<?php
/*
Plugin Name: Footer Backlinks
Description: Adds a footer link titled "We are listed at dyrectory.com" and up to four additional user-defined links. Go to: Settings >> Footer Backlinks to edit. 
Version: 1.1
Author: dyrectory.com
*/

// Hook the 'admin_menu' action hook, add the function named 'footer_link_menu' to it
add_action('admin_menu', 'footer_link_menu');

// Add a new submenu under Settings:
function footer_link_menu() {
    add_options_page(
        'Footer Backlinks Settings',
        'Footer Backlinks',
        'manage_options',
        'footer-link-plugin',
        'footer_link_settings_page'
    );
}

// Display the admin settings page
function footer_link_settings_page() {
    ?>
    <div class="wrap">
        <h2>Footer Backlinks Settings</h2>
        <form method="post" action="options.php">
            <?php
            settings_fields('footer-link-settings-group');
            do_settings_sections('footer-link-plugin');
            submit_button();
            ?>
        </form>
    </div>
    <?php
}

// Register and define the settings
add_action('admin_init', 'footer_link_settings');

function footer_link_settings() {
    register_setting('footer-link-settings-group', 'footer_link_1');
    register_setting('footer-link-settings-group', 'footer_link_2');
    register_setting('footer-link-settings-group', 'footer_link_3');
    register_setting('footer-link-settings-group', 'footer_link_4');

    add_settings_section('footer_link_section', 'Footer Link Settings', 'footer_link_section_callback', 'footer-link-plugin');

    add_settings_field('footer_link_1', 'Footer Link 1', 'footer_link_1_callback', 'footer-link-plugin', 'footer_link_section');
    add_settings_field('footer_link_2', 'Footer Link 2', 'footer_link_2_callback', 'footer-link-plugin', 'footer_link_section');
    add_settings_field('footer_link_3', 'Footer Link 3', 'footer_link_3_callback', 'footer-link-plugin', 'footer_link_section');
    add_settings_field('footer_link_4', 'Footer Link 4', 'footer_link_4_callback', 'footer-link-plugin', 'footer_link_section');
}

function footer_link_section_callback() {
    echo 'Enter up to four additional footer backlinks:';
}

function footer_link_1_callback() {
    $footer_link_1 = esc_attr(get_option('footer_link_1'));
    echo '<input type="text" name="footer_link_1" value="'.$footer_link_1.'" placeholder="example.com"/>';
}

function footer_link_2_callback() {
    $footer_link_2 = esc_attr(get_option('footer_link_2'));
    echo '<input type="text" name="footer_link_2" value="'.$footer_link_2.'" placeholder="example.com"/>';
}

function footer_link_3_callback() {
    $footer_link_3 = esc_attr(get_option('footer_link_3'));
    echo '<input type="text" name="footer_link_3" value="'.$footer_link_3.'" placeholder="example.com"/>';
}

function footer_link_4_callback() {
    $footer_link_4 = esc_attr(get_option('footer_link_4'));
    echo '<input type="text" name="footer_link_4" value="'.$footer_link_4.'" placeholder="example.com"/>';
}

// Hook the 'wp_footer' action hook, add the function named 'add_footer_links' to it
add_action('wp_footer', 'add_footer_links');

// Define 'add_footer_links'
function add_footer_links() {
    $footer_link_1 = esc_attr(get_option('footer_link_1'));
    $footer_link_2 = esc_attr(get_option('footer_link_2'));
    $footer_link_3 = esc_attr(get_option('footer_link_3'));
    $footer_link_4 = esc_attr(get_option('footer_link_4'));

    echo '<div style="text-align: center; margin: 20px 0; display: flex; flex-wrap: wrap; justify-content: center;">';
    echo '<p style="margin: 0 10px;">We are listed at <a href="https://dyrectory.com" target="_blank">dyrectory.com</a></p>';

    if ($footer_link_1) {
        echo '<p style="margin: 0 10px;"><a href="https://' . $footer_link_1 . '" target="_blank">' . $footer_link_1 . '</a></p>';
    }
    if ($footer_link_2) {
        echo '<p style="margin: 0 10px;"><a href="https://' . $footer_link_2 . '" target="_blank">' . $footer_link_2 . '</a></p>';
    }
    if ($footer_link_3) {
        echo '<p style="margin: 0 10px;"><a href="https://' . $footer_link_3 . '" target="_blank">' . $footer_link_3 . '</a></p>';
    }
    if ($footer_link_4) {
        echo '<p style="margin: 0 10px;"><a href="https://' . $footer_link_4 . '" target="_blank">' . $footer_link_4 . '</a></p>';
    }
    echo '</div>';

    echo '<style>
        @media (max-width: 767px) {
            .footer-link-container p {
                display: block;
                margin: 5px 0;
            }
        }
    </style>';
}
?>
